# coding: utf-8

"""
    Gentrace API

    These API routes are designed to ingest events from clients.  # noqa: E501

    The version of the OpenAPI document: 0.4.8
    Generated by: https://openapi-generator.tech
"""

from gentrace.paths.pipeline_run.post import PipelineRunPost


class IngestionApi(
    PipelineRunPost,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    pass
